==> lnschema_wetlab-0.3.3.tar.gz: lnschema_wetlab-0.3.3/docs/changelog.md <==
# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
🎨 Restrict `efo_id` to be unique | [14](https://github.com/laminlabs/lnschema-wetlab/pull/14) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-30 | 0.3.3
🎨 Updated biosample table to include more columns | [13](https://github.com/laminlabs/lnschema-wetlab/pull/13) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-28 | 0.3.2
🚚 Rename `readout_type` to `readout`, add descriptions | [12](https://github.com/laminlabs/lnschema-wetlab/pull/12) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-26 | 0.3.1
🏗️ Make table load configurable | [11](https://github.com/laminlabs/lnschema-wetlab/pull/11) | [falexwolf](https://github.com/falexwolf) | 2022-08-25 | 0.3.0
🎨 Default bio and tech samples | [10](https://github.com/laminlabs/lnschema-wetlab/pull/10) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-25 |
🐛 Imported additional tables | [9](https://github.com/laminlabs/lnschema-wetlab/pull/9) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-24 | 0.2.4
✨ Added `techsample` table | [8](https://github.com/laminlabs/lnschema-wetlab/pull/8) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-24 | 0.2.3
✏️ Fixed id type to int | [7](https://github.com/laminlabs/lnschema-wetlab/pull/7) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-23 | 0.2.2
✨ Added `experiment` and `experiment_type` tables. | [6](https://github.com/laminlabs/lnschema-wetlab/pull/6) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-23 | 0.2.1
🚚 Rename `lndb-schema-wetlab` to `lnschema-wetlab` | [5](https://github.com/laminlabs/lnschema-wetlab/pull/5) | [falexwolf](https://github.com/falexwolf) | 2022-08-19 | 0.2.0
🔧 Add schema module id | [4](https://github.com/laminlabs/lnschema-wetlab/pull/4) | [falexwolf](https://github.com/falexwolf) | 2022-08-18 |
🎨 Updated readout to use EFO | [3](https://github.com/laminlabs/lnschema-wetlab/pull/3) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-10 | 0.1.2
🐛 Add correct wetlab schema | [2](https://github.com/laminlabs/lnschema-wetlab/pull/2) | [falexwolf](https://github.com/falexwolf) | 2022-07-31 |
🚚 Add code from `lnschema-biology` | [1](https://github.com/laminlabs/lnschema-wetlab/pull/1) | [falexwolf](https://github.com/falexwolf) | 2022-07-31 | 0.1.0

==> lnschema_wetlab-0.3.4.tar.gz: lnschema_wetlab-0.3.4/docs/changelog.md <==
# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
🚚 Rename `project` to `project_id` in the experiment table | [15](https://github.com/laminlabs/lnschema-wetlab/pull/15) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-30 | 0.3.4
🎨 Restrict `efo_id` to be unique | [14](https://github.com/laminlabs/lnschema-wetlab/pull/14) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-30 | 0.3.3
🎨 Updated biosample table to include more columns | [13](https://github.com/laminlabs/lnschema-wetlab/pull/13) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-28 | 0.3.2
🚚 Rename `readout_type` to `readout`, add descriptions | [12](https://github.com/laminlabs/lnschema-wetlab/pull/12) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-26 | 0.3.1
🏗️ Make table load configurable | [11](https://github.com/laminlabs/lnschema-wetlab/pull/11) | [falexwolf](https://github.com/falexwolf) | 2022-08-25 | 0.3.0
🎨 Default bio and tech samples | [10](https://github.com/laminlabs/lnschema-wetlab/pull/10) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-25 |
🐛 Imported additional tables | [9](https://github.com/laminlabs/lnschema-wetlab/pull/9) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-24 | 0.2.4
✨ Added `techsample` table | [8](https://github.com/laminlabs/lnschema-wetlab/pull/8) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-24 | 0.2.3
✏️ Fixed id type to int | [7](https://github.com/laminlabs/lnschema-wetlab/pull/7) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-23 | 0.2.2
✨ Added `experiment` and `experiment_type` tables. | [6](https://github.com/laminlabs/lnschema-wetlab/pull/6) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-23 | 0.2.1
🚚 Rename `lndb-schema-wetlab` to `lnschema-wetlab` | [5](https://github.com/laminlabs/lnschema-wetlab/pull/5) | [falexwolf](https://github.com/falexwolf) | 2022-08-19 | 0.2.0
🔧 Add schema module id | [4](https://github.com/laminlabs/lnschema-wetlab/pull/4) | [falexwolf](https://github.com/falexwolf) | 2022-08-18 |
🎨 Updated readout to use EFO | [3](https://github.com/laminlabs/lnschema-wetlab/pull/3) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-10 | 0.1.2
🐛 Add correct wetlab schema | [2](https://github.com/laminlabs/lnschema-wetlab/pull/2) | [falexwolf](https://github.com/falexwolf) | 2022-07-31 |
🚚 Add code from `lnschema-biology` | [1](https://github.com/laminlabs/lnschema-wetlab/pull/1) | [falexwolf](https://github.com/falexwolf) | 2022-07-31 | 0.1.0
